@@ -1,12 +1,6 @@
-# Re-export Seurat generic
-#' @importFrom Seurat FoldChange
-#' @export
-Seurat::FoldChange
-
-#' @rdname FoldChange
-#' @export
+# dynamically exported, see zzz.R
 #' @method FoldChange ChromatinAssay
-#' @importFrom Seurat FoldChange GetAssayData
+#' @importFrom SeuratObject GetAssayData
 #' @importFrom Matrix rowMeans
 FoldChange.ChromatinAssay <- function(
   object,
@@ -20,6 +14,9 @@ FoldChange.ChromatinAssay <- function(
   base = 2,
   ...
 ) {
+  if (!requireNamespace(package = "Seurat", quietly = TRUE)) {
+    stop("Please install Seurat: install.packages('Seurat')")
+  }
   mean.fxn <-  function(x) {
     return(log(x = rowMeans(x = x) + pseudocount.use, base = base))
   }
@@ -31,7 +28,7 @@ FoldChange.ChromatinAssay <- function(
   )
   fc.name <- SetIfNull(x = fc.name, y = paste0("avg_log", base.text, "FC"))
   data <- GetAssayData(object = object, slot = slot)
-  FoldChange(
+  Seurat::FoldChange(
     object = data,
     cells.1 = cells.1,
     cells.2 = cells.2,
