@@ -93,6 +93,7 @@ Motif <- setClass(
 #'
 #' @name ChromatinAssay-class
 #' @rdname ChromatinAssay-class
+#' @importClassesFrom SeuratObject Assay
 #' @exportClass ChromatinAssay
 #' @concept assay
 ChromatinAssay <- setClass(
@@ -161,7 +162,7 @@ ChromatinAssay <- setClass(
 #' @param verbose Display messages
 #' @param ... Additional arguments passed to \code{\link{CreateFragmentObject}}
 #'
-#' @importFrom Seurat CreateAssayObject
+#' @importFrom SeuratObject CreateAssayObject
 #' @importFrom Matrix rowSums colSums
 #' @importFrom GenomicRanges isDisjoint
 #' @concept assay
@@ -500,7 +501,7 @@ CreateMotifObject <- function(
   return(motif.obj)
 }
 
-#' @importFrom Seurat GetAssayData
+#' @importFrom SeuratObject GetAssayData
 #' @method GetAssayData ChromatinAssay
 #' @export
 #' @concept assay
@@ -538,7 +539,7 @@ GetFragmentData <- function(object, slot = "path") {
 #' @export
 #' @concept motifs
 #' @examples
-#' motif.obj <- Seurat::GetAssayData(
+#' motif.obj <- SeuratObject::GetAssayData(
 #'   object = atac_small[['peaks']], slot = "motifs"
 #' )
 #' GetMotifData(object = motif.obj)
@@ -546,7 +547,7 @@ GetMotifData.Motif <- function(object, slot = "data", ...) {
   return(slot(object = object, name = slot))
 }
 
-#' @importFrom Seurat GetAssayData
+#' @importFrom SeuratObject GetAssayData
 #' @rdname GetMotifData
 #' @concept motifs
 #' @method GetMotifData ChromatinAssay
@@ -564,21 +565,20 @@ GetMotifData.ChromatinAssay <- function(object, slot = "data", ...) {
 #' @rdname GetMotifData
 #' @method GetMotifData Seurat
 #' @concept motifs
-#' @importFrom Seurat DefaultAssay GetAssay
+#' @importFrom SeuratObject DefaultAssay
 #' @export
 #' @examples
 #' GetMotifData(object = atac_small)
 GetMotifData.Seurat <- function(object, assay = NULL, slot = "data", ...) {
   assay <- SetIfNull(x = assay, y = DefaultAssay(object = object))
   return(GetMotifData(
-    object = GetAssay(object = object, assay = assay),
+    object = object[[assay]],
     slot = slot,
     ...
   ))
 }
 
-#' @importFrom Seurat RenameCells
-#' @importFrom Seurat GetAssayData
+#' @importFrom SeuratObject RenameCells GetAssayData
 #' @concept assay
 #' @method RenameCells ChromatinAssay
 #' @export
@@ -593,9 +593,11 @@ RenameCells.ChromatinAssay <- function(object, new.names = NULL, ...) {
   pos.enrich <- GetAssayData(object = object, slot = "positionEnrichment")
   for (i in seq_along(along.with = pos.enrich)) {
     mat <- pos.enrich[[i]]
-    mat <- mat[colnames(x = object), ]
-    rownames(x = mat) <- new.names[rownames(x = mat)]
-    pos.enrich[[i]] <- mat
+    if (!inherits(x = mat, what = "list")) {
+      mat <- mat[colnames(x = object), ]
+      rownames(x = mat) <- new.names[rownames(x = mat)]
+      pos.enrich[[i]] <- mat
+    }
   }
   slot(object = object, name = "positionEnrichment") <- pos.enrich
 
@@ -612,7 +614,7 @@ RenameCells.ChromatinAssay <- function(object, new.names = NULL, ...) {
   return(object)
 }
 
-#' @importFrom Seurat RenameCells
+#' @importFrom SeuratObject RenameCells
 #' @concept fragments
 #' @method RenameCells Fragment
 #' @export
@@ -628,7 +630,7 @@ RenameCells.Fragment <- function(object, new.names, ...) {
   return(object)
 }
 
-#' @importFrom Seurat SetAssayData
+#' @importFrom SeuratObject SetAssayData
 #' @importFrom GenomeInfoDb genome Seqinfo
 #' @method SetAssayData ChromatinAssay
 #' @concept assay
@@ -784,7 +786,7 @@ SetAssayData.ChromatinAssay <- function(object, slot, new.data, ...) {
 #' @export
 #' @concept motifs
 #' @examples
-#' motif.obj <- Seurat::GetAssayData(
+#' motif.obj <- SeuratObject::GetAssayData(
 #'   object = atac_small[['peaks']], slot = "motifs"
 #' )
 #' SetMotifData(object = motif.obj, slot = 'data', new.data = matrix())
@@ -808,7 +810,7 @@ SetMotifData.Motif <- function(object, slot, new.data, ...) {
 
 #' @param new.data motif matrix to add. Should be matrix or sparse matrix class
 #' @param slot Name of slot to use
-#' @importFrom Seurat GetAssayData SetAssayData
+#' @importFrom SeuratObject GetAssayData SetAssayData
 #' @rdname SetMotifData
 #' @export
 #' @concept motifs
@@ -850,7 +852,7 @@ SetMotifData.ChromatinAssay <- function(object, slot, new.data, ...) {
 
 #' @param assay Name of assay whose data should be set
 #' @rdname SetMotifData
-#' @importFrom Seurat DefaultAssay
+#' @importFrom SeuratObject DefaultAssay
 #' @export
 #' @method SetMotifData Seurat
 #' @concept motifs
@@ -883,7 +885,7 @@ SetMotifData.Seurat <- function(object, assay = NULL, ...) {
 #' @export
 #' @concept motifs
 #' @examples
-#' motif.obj <- Seurat::GetAssayData(
+#' motif.obj <- SeuratObject::GetAssayData(
 #'   object = atac_small[['peaks']], slot = "motifs"
 #' )
 #' subset(x = motif.obj, features = head(rownames(motif.obj), 10))
@@ -910,7 +912,7 @@ subset.Motif <- function(x, features = NULL, motifs = NULL, ...) {
 }
 
 #' @export
-#' @importClassesFrom Seurat Assay
+#' @importClassesFrom SeuratObject Assay
 #' @concept assay
 #' @method subset ChromatinAssay
 subset.ChromatinAssay <- function(
@@ -977,7 +979,7 @@ subset.ChromatinAssay <- function(
 #' @concept assay
 #' @method merge ChromatinAssay
 #' @importFrom GenomicRanges union findOverlaps
-#' @importFrom Seurat RowMergeSparseMatrices
+#' @importFrom SeuratObject RowMergeSparseMatrices
 #' @importFrom S4Vectors subjectHits queryHits mcols
 #' @importMethodsFrom GenomeInfoDb merge
 merge.ChromatinAssay <- function(
@@ -1311,7 +1313,7 @@ merge.ChromatinAssay <- function(
 #' @concept motifs
 #' @method [ Motif
 #' @examples
-#' motif.obj <- Seurat::GetAssayData(
+#' motif.obj <- SeuratObject::GetAssayData(
 #'   object = atac_small, assay = 'peaks', slot = 'motifs'
 #' )
 #' motif.obj[1:10,1:10]
@@ -1431,7 +1433,7 @@ Annotation.ChromatinAssay <- function(object, ...) {
 }
 
 #' @param object A Seurat object or ChromatinAssay object
-#' @importFrom Seurat DefaultAssay
+#' @importFrom SeuratObject DefaultAssay
 #' @rdname Annotation
 #' @method Annotation Seurat
 #' @export
@@ -1457,7 +1459,7 @@ Fragments.ChromatinAssay <- function(object, ...) {
 }
 
 #' @param object A Seurat object or ChromatinAssay object
-#' @importFrom Seurat DefaultAssay
+#' @importFrom SeuratObject DefaultAssay
 #' @rdname Fragments
 #' @method Fragments Seurat
 #' @export
@@ -1483,7 +1485,7 @@ Motifs.ChromatinAssay <- function(object, ...) {
 
 #' @param object A Seurat object
 #' @rdname Motifs
-#' @importFrom Seurat DefaultAssay
+#' @importFrom SeuratObject DefaultAssay
 #' @method Motifs Seurat
 #' @export
 #' @concept assay
@@ -1509,7 +1511,7 @@ Links.ChromatinAssay <- function(object, ...) {
 #' @param object A Seurat object
 #' @rdname Links
 #' @method Links Seurat
-#' @importFrom Seurat DefaultAssay
+#' @importFrom SeuratObject DefaultAssay
 #' @export
 #' @concept links
 #' @concept assay
@@ -1550,7 +1552,7 @@ dim.Motif <- function(x) {
 #' @export
 #' @rdname Motifs
 #' @method Motifs<- Seurat
-#' @importFrom Seurat DefaultAssay
+#' @importFrom SeuratObject DefaultAssay
 #' @concept assay
 #' @concept motifs
 #' @examples
@@ -1602,7 +1604,7 @@ dim.Motif <- function(x) {
 }
 
 #' @export
-#' @importFrom Seurat DefaultAssay
+#' @importFrom SeuratObject DefaultAssay
 #' @method Annotation<- Seurat
 #' @concept assay
 #' @rdname Annotation
@@ -1618,7 +1620,7 @@ dim.Motif <- function(x) {
 #' @export
 #' @method Fragments<- ChromatinAssay
 #' @rdname Fragments
-#' @importFrom Seurat SetAssayData
+#' @importFrom SeuratObject SetAssayData
 #' @concept assay
 #' @concept fragments
 #' @examples
@@ -1655,7 +1657,7 @@ dim.Motif <- function(x) {
 #' @rdname Fragments
 #' @concept assay
 #' @concept fragments
-#' @importFrom Seurat DefaultAssay
+#' @importFrom SeuratObject DefaultAssay
 #' @examples
 #' fpath <- system.file("extdata", "fragments.tsv.gz", package="Signac")
 #' fragments <- CreateFragmentObject(
